@@ -106,9 +106,9 @@ static guint machine_signals[LAST_SIGNAL];
 GType
 ags_machine_get_type(void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_machine = 0;
 
     static const GTypeInfo ags_machine_info = {
@@ -137,10 +137,10 @@ ags_machine_get_type(void)
 				AGS_TYPE_CONNECTABLE,
 				&ags_connectable_interface_info);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_machine);
+    g_once_init_leave(&g_define_type_id__static, ags_type_machine);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
