@@ -90,9 +90,9 @@ enum{
 GType
 ags_track_mapper_get_type(void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_track_mapper = 0;
 
     static const GTypeInfo ags_track_mapper_info = {
@@ -131,10 +131,10 @@ ags_track_mapper_get_type(void)
 				AGS_TYPE_APPLICABLE,
 				&ags_applicable_interface_info);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_track_mapper);
+    g_once_init_leave(&g_define_type_id__static, ags_type_track_mapper);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
