@@ -63,9 +63,9 @@ static AgsConnectableInterface *ags_fm_synth_parent_connectable_interface;
 GType
 ags_fm_synth_get_type(void)
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_fm_synth = 0;
 
     static const GTypeInfo ags_fm_synth_info = {
@@ -94,10 +94,10 @@ ags_fm_synth_get_type(void)
 				AGS_TYPE_CONNECTABLE,
 				&ags_connectable_interface_info);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_fm_synth);
+    g_once_init_leave(&g_define_type_id__static, ags_type_fm_synth);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
