@@ -43,9 +43,9 @@ const gchar *ags_fx_playback_channel_plugin_name = "ags-fx-playback";
 GType
 ags_fx_playback_channel_get_type()
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_fx_playback_channel = 0;
 
     static const GTypeInfo ags_fx_playback_channel_info = {
@@ -65,10 +65,10 @@ ags_fx_playback_channel_get_type()
 							  &ags_fx_playback_channel_info,
 							  0);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_fx_playback_channel);
+    g_once_init_leave(&g_define_type_id__static, ags_type_fx_playback_channel);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
