@@ -132,6 +132,7 @@
 #include <ags/audio/ags_sf2_synth_util.h>
 #include <ags/audio/ags_sfz_synth_generator.h>
 #include <ags/audio/ags_sfz_synth_util.h>
+#include <ags/audio/ags_star_synth_util.h>
 #include <ags/audio/ags_track.h>
 #include <ags/audio/ags_tremolo_util.h>
 #include <ags/audio/ags_vector_256_manager.h>
@@ -302,6 +303,12 @@
 #include <ags/audio/fx/ags_fx_fm_synth_channel.h>
 #include <ags/audio/fx/ags_fx_fm_synth_channel_processor.h>
 #include <ags/audio/fx/ags_fx_fm_synth_recycling.h>
+#include <ags/audio/fx/ags_fx_star_synth_audio.h>
+#include <ags/audio/fx/ags_fx_star_synth_audio_processor.h>
+#include <ags/audio/fx/ags_fx_star_synth_audio_signal.h>
+#include <ags/audio/fx/ags_fx_star_synth_channel.h>
+#include <ags/audio/fx/ags_fx_star_synth_channel_processor.h>
+#include <ags/audio/fx/ags_fx_star_synth_recycling.h>
 #include <ags/audio/fx/ags_fx_high_pass_audio.h>
 #include <ags/audio/fx/ags_fx_high_pass_audio_processor.h>
 #include <ags/audio/fx/ags_fx_high_pass_audio_signal.h>
